baseObjects.ResultSetItem

|  | ## Cheshire3 Object Model: Class ResultSetItem

Module baseObjects :: Class ResultSetItem

## Class ResultSetItem
source code

Object Tree:

    object --+
             |
            ResultSetItem

Known Subclasses:
  resultSet.SimpleResultSetItem

An object representing a pointer to a Record, with result set specific metadata.
Instance Methods

Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

docid |
occurences |
recordStore |
Inherited from `object`: `__class__`

Class Variable Details

    ### docid Value:
        0

    ### occurences Value:
        0

    ### recordStore Value:
        ''